==> openshift-model-hive-6.7.2-sources.jar: io/fabric8/openshift/api/model/hive/v1/FailedProvisionAWSConfigBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class FailedProvisionAWSConfigBuilder extends FailedProvisionAWSConfigFluentImpl<FailedProvisionAWSConfigBuilder> implements VisitableBuilder<FailedProvisionAWSConfig,FailedProvisionAWSConfigBuilder>{
  public FailedProvisionAWSConfigBuilder() {
    this(false);
  }
  public FailedProvisionAWSConfigBuilder(Boolean validationEnabled) {
    this(new FailedProvisionAWSConfig(), validationEnabled);
  }
  public FailedProvisionAWSConfigBuilder(FailedProvisionAWSConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public FailedProvisionAWSConfigBuilder(FailedProvisionAWSConfigFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new FailedProvisionAWSConfig(), validationEnabled);
  }
  public FailedProvisionAWSConfigBuilder(FailedProvisionAWSConfigFluent<?> fluent,FailedProvisionAWSConfig instance) {
    this(fluent, instance, false);
  }
  public FailedProvisionAWSConfigBuilder(FailedProvisionAWSConfigFluent<?> fluent,FailedProvisionAWSConfig instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withBucket(instance.getBucket());
      fluent.withCredentialsSecretRef(instance.getCredentialsSecretRef());
      fluent.withRegion(instance.getRegion());
      fluent.withServiceEndpoint(instance.getServiceEndpoint());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public FailedProvisionAWSConfigBuilder(FailedProvisionAWSConfig instance) {
    this(instance,false);
  }
  public FailedProvisionAWSConfigBuilder(FailedProvisionAWSConfig instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withBucket(instance.getBucket());
      this.withCredentialsSecretRef(instance.getCredentialsSecretRef());
      this.withRegion(instance.getRegion());
      this.withServiceEndpoint(instance.getServiceEndpoint());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  FailedProvisionAWSConfigFluent<?> fluent;
  Boolean validationEnabled;
  public FailedProvisionAWSConfig build() {
    FailedProvisionAWSConfig buildable = new FailedProvisionAWSConfig(fluent.getBucket(),fluent.getCredentialsSecretRef(),fluent.getRegion(),fluent.getServiceEndpoint());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-hive-6.8.0-sources.jar: io/fabric8/openshift/api/model/hive/v1/FailedProvisionAWSConfigBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class FailedProvisionAWSConfigBuilder extends FailedProvisionAWSConfigFluent<FailedProvisionAWSConfigBuilder> implements VisitableBuilder<FailedProvisionAWSConfig,FailedProvisionAWSConfigBuilder>{
  public FailedProvisionAWSConfigBuilder() {
    this(false);
  }
  public FailedProvisionAWSConfigBuilder(Boolean validationEnabled) {
    this(new FailedProvisionAWSConfig(), validationEnabled);
  }
  public FailedProvisionAWSConfigBuilder(FailedProvisionAWSConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public FailedProvisionAWSConfigBuilder(FailedProvisionAWSConfigFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new FailedProvisionAWSConfig(), validationEnabled);
  }
  public FailedProvisionAWSConfigBuilder(FailedProvisionAWSConfigFluent<?> fluent,FailedProvisionAWSConfig instance) {
    this(fluent, instance, false);
  }
  public FailedProvisionAWSConfigBuilder(FailedProvisionAWSConfigFluent<?> fluent,FailedProvisionAWSConfig instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new FailedProvisionAWSConfig());

    if (instance != null) {
      fluent.withBucket(instance.getBucket());
      fluent.withCredentialsSecretRef(instance.getCredentialsSecretRef());
      fluent.withRegion(instance.getRegion());
      fluent.withServiceEndpoint(instance.getServiceEndpoint());
      fluent.withBucket(instance.getBucket());
      fluent.withCredentialsSecretRef(instance.getCredentialsSecretRef());
      fluent.withRegion(instance.getRegion());
      fluent.withServiceEndpoint(instance.getServiceEndpoint());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public FailedProvisionAWSConfigBuilder(FailedProvisionAWSConfig instance) {
    this(instance,false);
  }
  public FailedProvisionAWSConfigBuilder(FailedProvisionAWSConfig instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new FailedProvisionAWSConfig());

    if (instance != null) {
      this.withBucket(instance.getBucket());
      this.withCredentialsSecretRef(instance.getCredentialsSecretRef());
      this.withRegion(instance.getRegion());
      this.withServiceEndpoint(instance.getServiceEndpoint());
      this.withBucket(instance.getBucket());
      this.withCredentialsSecretRef(instance.getCredentialsSecretRef());
      this.withRegion(instance.getRegion());
      this.withServiceEndpoint(instance.getServiceEndpoint());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  FailedProvisionAWSConfigFluent<?> fluent;
  Boolean validationEnabled;
  public FailedProvisionAWSConfig build() {
    FailedProvisionAWSConfig buildable = new FailedProvisionAWSConfig(fluent.getBucket(),fluent.buildCredentialsSecretRef(),fluent.getRegion(),fluent.getServiceEndpoint());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
